@@ -6,9 +6,9 @@ from south.v2 import SchemaMigration
 from django.db import models
 
 class Migration(SchemaMigration):
-    
+
     def forwards(self, orm):
-        
+
         # Deleting field 'BlogPost._keywords'
         db.delete_column('blog_blogpost', '_keywords')
 
@@ -17,10 +17,10 @@ class Migration(SchemaMigration):
 
         # Removing M2M table for field keywords on 'BlogPost'
         db.delete_table('blog_blogpost_keywords')
-    
-    
+
+
     def backwards(self, orm):
-        
+
         # Adding field 'BlogPost._keywords'
         db.add_column('blog_blogpost', '_keywords', self.gf('django.db.models.fields.CharField')(default='', max_length=500), keep_default=False)
 
@@ -34,8 +34,8 @@ class Migration(SchemaMigration):
             ('keyword', models.ForeignKey(orm['core.keyword'], null=False))
         ))
         db.create_unique('blog_blogpost_keywords', ['blogpost_id', 'keyword_id'])
-    
-    
+
+
     models = {
         'auth.group': {
             'Meta': {'object_name': 'Group'},
@@ -75,13 +75,13 @@ class Migration(SchemaMigration):
         'blog.blogpost': {
             'Meta': {'object_name': 'BlogPost'},
             'categories': ('django.db.models.fields.related.ManyToManyField', [], {'symmetrical': 'False', 'related_name': "'blogposts'", 'blank': 'True', 'to': "orm['blog.BlogCategory']"}),
-            'comments': ('mezzanine.generic.fields.CommentsField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.ThreadedComment']"}),
+            #'comments': ('mezzanine.generic.fields.CommentsField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.ThreadedComment']"}),
             'comments_count': ('django.db.models.fields.IntegerField', [], {'default': '0'}),
             'content': ('mezzanine.core.fields.HtmlField', [], {}),
             'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
             'expiry_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
             'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
-            'keywords': ('mezzanine.generic.fields.KeywordsField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.AssignedKeyword']"}),
+            #'keywords': ('mezzanine.generic.fields.KeywordsField', [], {'object_id_field': "'object_pk'", 'to': "orm['generic.AssignedKeyword']"}),
             'keywords_string': ('django.db.models.fields.CharField', [], {'max_length': '500', 'blank': 'True'}),
             'publish_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
             'short_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
@@ -140,5 +140,5 @@ class Migration(SchemaMigration):
             'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
         }
     }
-    
+
     complete_apps = ['blog']
