@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+
+from future.utils import native_str
 
 from django.contrib import admin
 from django.contrib.auth import logout
@@ -36,7 +39,9 @@ class _Deprecated(object):
         warn(msg)
 
 for old, new in _deprecated.items():
-    globals()[old] = type(old, (_Deprecated,), {"old": old, "new": new})
+    globals()[old] = type(native_str(old),
+                          (_Deprecated,),
+                          {"old": old, "new": new})
 
 
 class AdminLoginInterfaceSelectorMiddleware(object):
@@ -91,8 +96,10 @@ class TemplateForDeviceMiddleware(object):
     """
     def process_template_response(self, request, response):
         if hasattr(response, "template_name"):
-            templates = templates_for_device(request, response.template_name)
-            response.template_name = templates
+            if not isinstance(response.template_name, Template):
+                templates = templates_for_device(request,
+                    response.template_name)
+                response.template_name = templates
         return response
 
 
@@ -102,8 +109,10 @@ class TemplateForHostMiddleware(object):
     """
     def process_template_response(self, request, response):
         if hasattr(response, "template_name"):
-            templates = templates_for_host(request, response.template_name)
-            response.template_name = templates
+            if not isinstance(response.template_name, Template):
+                templates = templates_for_host(request,
+                    response.template_name)
+                response.template_name = templates
         return response
 
 
@@ -140,8 +149,14 @@ class UpdateCacheMiddleware(object):
         # content. Split on the delimiter the ``nevercache`` tag
         # wrapped its contents in, and render only the content
         # enclosed by it, to avoid possible template code injection.
-        parts = response.content.split(nevercache_token())
-        if response["content-type"].startswith("text") and len(parts) > 1:
+        token = nevercache_token()
+        try:
+            token = token.encode('utf-8')
+        except AttributeError:
+            pass
+        parts = response.content.split(token)
+        content_type = response.get("content-type", "")
+        if content_type.startswith("text") and len(parts) > 1:
             # Restore csrf token from cookie - check the response
             # first as it may be being set for the first time.
             csrf_token = None
@@ -159,7 +174,7 @@ class UpdateCacheMiddleware(object):
                 if i % 2:
                     part = Template(part).render(context).encode("utf-8")
                 parts[i] = part
-            response.content = "".join(parts)
+            response.content = b"".join(parts)
             response["Content-Length"] = len(response.content)
             if hasattr(request, '_messages'):
                 # Required to clear out user messages.
