@@ -630,7 +630,9 @@ def translate_url(context, language):
     current_language = translation.get_language()
     translation.activate(language)
     try:
-        url = reverse(view.url_name, args=view.args, kwargs=view.kwargs)
+        url_name = (view.url_name if not view.namespace
+                    else '%s:%s' % (view.namespace, view.url_name))
+        url = reverse(url_name, args=view.args, kwargs=view.kwargs)
     except NoReverseMatch:
         url_name = "admin:" + view.url_name
         url = reverse(url_name, args=view.args, kwargs=view.kwargs)
